StartAppAdPreferences class

Constructors

StartAppAdPreferences({String? adTag, String? keywords, String? gender, int? age, bool? videoMuted, bool? hardwareAccelerated, List<String>? categories, List<String>? categoriesExclude, int? desiredWidth, int? desiredHeight, double? minCPM})
const

Properties

adTag → String?
Ad tag is used to distinguish different placements within your app. Also know as 'ad unit', 'placement id', etc.
final
age → int?
Pass age of your user if you know it.
final
categories → List<String>?
Pass categories of the ad you want to load.
final
categoriesExclude → List<String>?
Pass categories of the ad you do not want to load.
final
desiredHeight → int?
Desired height of an ad. Only applicable for StartAppBannerAd.
final
desiredWidth → int?
Desired width of an ad. Only applicable for StartAppBannerAd.
final
gender → String?
Pass gender of your user if you know it.
final
hardwareAccelerated → bool?
Pass true if you prefer to use hardware acceleration.
final
hashCode → int
The hash code for this object.
no setterinherited
keywords → String?
Specify keywords of the content within certain placement within your app.
final
minCPM → double?
Minimal cost per impression for loaded ads.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoMuted → bool?
Pass true if you prefer to mute video ad.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited