StartAppNativeAd class

Proxy object which holds a native ad ready to be shown.

Properties

callToAction → String?
Title which must be displayed within the main button of an ad.
no setter
campaign → String?
Type of campaign.
no setter
category → String?
Category of app or website.
no setter
description → String?
The secondary text of an ad, which must have less visual accent comparing to the title.
no setter
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String?
URL of the main image of an ad.
no setter
installs → String?
Number of app installs.
no setter
rating → double?
Rating of an app or website which is advertised.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryImageUrl → String?
URL of the secondary image of an ad.
no setter
title → String?
The main line of an ad, which must stands out well
no setter

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited