StartAppSdk class

Singleton class for accessing API of native platform Start.io (StartApp) SDK.

Constructors

StartAppSdk()
It's safe to call this constructor several time, it returns singleton instance.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
onAdClickedCallbacks → Map<int, VoidCallback>
final
onAdDisplayedCallbacks → Map<int, VoidCallback>
final
onAdHiddenCallbacks → Map<int, VoidCallback>
final
onAdImpressionCallbacks → Map<int, VoidCallback>
final
onAdNotDisplayedCallbacks → Map<int, VoidCallback>
final
onVideoCompletedCallbacks → Map<int, VoidCallback>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSdkVersion() → Future
Returns the version of underlying native platform SDK.
loadBannerAd(StartAppBannerType type, {StartAppAdPreferences prefs = const StartAppAdPreferences(), VoidCallback? onAdImpression, VoidCallback? onAdClicked}) → Future<StartAppBannerAd>
Loads banner ad, creates an underlying native platform view.
loadInterstitialAd({StartAppInterstitialAdMode mode = StartAppInterstitialAdMode.automatic, StartAppAdPreferences prefs = const StartAppAdPreferences(), VoidCallback? onAdDisplayed, VoidCallback? onAdNotDisplayed, VoidCallback? onAdClicked, VoidCallback? onAdHidden, VoidCallback? onAdImpression}) → Future<StartAppInterstitialAd>
Loads interstitial ad, does not create an underlying native platform view.
loadNativeAd({StartAppAdPreferences prefs = const StartAppAdPreferences(), VoidCallback? onAdImpression, VoidCallback? onAdClicked}) → Future<StartAppNativeAd>
Loads native ad, does not create an underlying native platform view.
loadRewardedVideoAd({StartAppAdPreferences prefs = const StartAppAdPreferences(), VoidCallback? onAdDisplayed, VoidCallback? onAdNotDisplayed, VoidCallback? onAdClicked, VoidCallback? onAdHidden, VoidCallback? onAdImpression, VoidCallback? onVideoCompleted}) → Future<StartAppRewardedVideoAd>
Loads rewarded video ad, does not create an underlying native platform view.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTestAdsEnabled(bool value) → Future
Enables test ads.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited